package pathgame;

import me.hammerle.snuviengine.api.IGame;
import me.hammerle.snuviengine.api.KeyBinding;
import me.hammerle.snuviengine.api.KeyHandler;
import me.hammerle.snuviengine.api.Renderer;
import org.lwjgl.glfw.GLFW;
import pathgame.rendering.TileMapRenderer;
import pathgame.tilemap.TileMap;
import pathgame.utils.TestUtils;

public class PathGame implements IGame
{
    private final TileMapRenderer mapRenderer = new TileMapRenderer();
    private final TileMap map = TestUtils.getTestMap(25, 15);
    
    private final static KeyBinding ZOOM_IN = KeyHandler.register(GLFW.GLFW_KEY_UP);
    private final static KeyBinding ZOOM_OUT = KeyHandler.register(GLFW.GLFW_KEY_DOWN);
    
    private final static KeyBinding UP = KeyHandler.register(GLFW.GLFW_KEY_W);
    private final static KeyBinding DOWN = KeyHandler.register(GLFW.GLFW_KEY_S);
    private final static KeyBinding LEFT = KeyHandler.register(GLFW.GLFW_KEY_A);
    private final static KeyBinding RIGHT = KeyHandler.register(GLFW.GLFW_KEY_D);
    
    private float x = 0.0f;
    private float y = 0.0f;
    
    public PathGame()
    {
    }
    
    @Override
    public void tick()
    {
        mapRenderer.tick();
        
        if(ZOOM_IN.isDown())
        {
            mapRenderer.setScale(mapRenderer.getScale() * 1.05f);
        }
        if(ZOOM_OUT.isDown())
        {
            mapRenderer.setScale(mapRenderer.getScale() / 1.05f);
        }
        
        if(UP.isDown())
        {
            y -= 20;
        }
        if(DOWN.isDown())
        {
            y += 20;
        }
        if(LEFT.isDown())
        {
            x -= 20;
        }
        if(RIGHT.isDown())
        {
            x += 20;
        }
    }
    
    @Override
    public void renderTick(Renderer r, float lag)
    {
        mapRenderer.renderTick(map, r, false, x, y);
        
        r.translateTo(0.0f, 0.0f);
        r.updateMatrix();
        r.setTextureEnabled(false);
        r.setColorEnabled(true);
        r.getColorRenderer().drawRectangle(0, 0, mapRenderer.getWidth(map), 10, 0xFF0000FF);
        r.getColorRenderer().drawRectangle(0, 0, 10, mapRenderer.getHeight(map), 0xFF0000FF);
    }

    @Override
    public void onStop()
    {
    }
}
