package pathgame.rendering;

import pathgame.tilemap.Tile;
import pathgame.tilemap.TileMap;
import pathgame.tilemap.Tiles;

public class TileRenderer
{
    /** The unscaled render size of a map tile. */
    public final static float TILE_SIZE = 16;
    
    private static TileTextureProvider[] tProviders = new TileTextureProvider[8];
    
    private static void register(Tile t, TileTextureProvider provider)
    {
        if(t.getId() >= tProviders.length)
        {
            TileTextureProvider[] newTProviders = new TileTextureProvider[t.getId()];
            System.arraycopy(tProviders, 0, newTProviders, 0, tProviders.length);
            tProviders = newTProviders;
        }
        tProviders[t.getId()] = provider;
    }
    
    static
    {
        register(Tiles.GRASS, new StaticTextureProvider(TileTexture.fromTextureId(0)));
        register(Tiles.HILL, new StaticTextureProvider(TileTexture.fromTextureId(1)));
        register(Tiles.MOUNTAIN, new StaticTextureProvider(TileTexture.fromTextureId(2)));
    }
    
    public static TileTexture getTileTexture(TileMap map, Tile t, int x, int y)
    {
        if(t == null)
        {
            return null;
        }
        int id = t.getId();
        if(id < 0 || id >= tProviders.length || tProviders[id] == null)
        {
            return null;
        }
        return tProviders[id].getTexture(map, t, x, y);
    }
}
